package_name = 'dploi_fabric'
name = 'dploi-fabric'
author = 'Benjamin Wohlwend, Kristian Oellegaard, Stefan Foulis'
author_email = 'developers@divio.ch'
description = "A collection of fabric tasks"
version = __import__(package_name).__version__
project_url = 'http://github.com/dploi/%s' % name
license = 'TBA'
